@@ -42,8 +42,10 @@ html_theme = "furo"
 # See sphinx-doc/sphinx#10785
 _TYPE_ALIASES = dict(
     AnchorType=("class", "Anchor"),
+    D=("data", "D"),
     ObjectSchema=("data", "ObjectSchema"),
     Schema=("data", "Schema"),
+    URI=("attr", "URI"),  # ?!?!?! Sphinx...
 )
 
 
@@ -51,7 +53,10 @@ def _resolve_broken_refs(app, env, node, contnode):
     if node["refdomain"] != "py":
         return
 
-    kind, target = _TYPE_ALIASES.get(node["reftarget"], (None, None))
+    if node["reftarget"].startswith("referencing.typing."):
+        kind, target = "data", node["reftarget"]
+    else:
+        kind, target = _TYPE_ALIASES.get(node["reftarget"], (None, None))
     if kind is not None:
         return app.env.get_domain("py").resolve_xref(
             env,
