@@ -9,6 +9,15 @@ from referencing._attrs import frozen
 from referencing.typing import URI
 
 
+@frozen
+class NoSuchResource(KeyError):
+    """
+    The given URI is not present in a registry.
+    """
+
+    ref: URI
+
+
 @frozen
 class CannotDetermineSpecification(Exception):
     """
@@ -45,3 +54,18 @@ class PointerToNowhere(Unresolvable):
 
     def __str__(self):
         return f"{self.ref!r} does not exist within {self.resource.contents!r}"
+
+
+@frozen
+class NoSuchAnchor(Unresolvable):
+    """
+    An anchor does not exist within a particular resource.
+    """
+
+    resource: Any
+    anchor: str
+
+    def __str__(self):
+        return (
+            f"{self.anchor!r} does not exist within {self.resource.contents!r}"
+        )
