@@ -150,63 +150,183 @@ def _subresources_of(
     return subresources_of
 
 
+def _subresources_of_with_crazy_items(
+    in_value: Set[str] = frozenset(),
+    in_subvalues: Set[str] = frozenset(),
+    in_subarray: Set[str] = frozenset(),
+):
+    """
+    Specifically handle older drafts where there are some funky keywords.
+    """
+
+    def subresources_of(contents: Schema) -> Iterable[ObjectSchema]:
+        if isinstance(contents, bool):
+            return
+        for each in in_value:
+            if each in contents:
+                yield contents[each]
+        for each in in_subarray:
+            if each in contents:
+                yield from contents[each]
+        for each in in_subvalues:
+            if each in contents:
+                yield from contents[each].values()
+
+        items = contents.get("items")
+        if items is not None:
+            if isinstance(items, Mapping):
+                yield items
+            else:
+                yield from items
+
+    return subresources_of
+
+
+def _subresources_of_with_crazy_items_dependencies(
+    in_value: Set[str] = frozenset(),
+    in_subvalues: Set[str] = frozenset(),
+    in_subarray: Set[str] = frozenset(),
+):
+    """
+    Specifically handle older drafts where there are some funky keywords.
+    """
+
+    def subresources_of(contents: Schema) -> Iterable[ObjectSchema]:
+        if isinstance(contents, bool):
+            return
+        for each in in_value:
+            if each in contents:
+                yield contents[each]
+        for each in in_subarray:
+            if each in contents:
+                yield from contents[each]
+        for each in in_subvalues:
+            if each in contents:
+                yield from contents[each].values()
+
+        items = contents.get("items")
+        if items is not None:
+            if isinstance(items, Mapping):
+                yield items
+            else:
+                yield from items
+        dependencies = contents.get("dependencies")
+        if dependencies is not None:
+            values = iter(dependencies.values())
+            value = next(values, None)
+            if isinstance(value, Mapping):
+                yield value
+                yield from values
+
+    return subresources_of
+
+
 DRAFT202012 = Specification(
     name="draft2020-12",
     id_of=_dollar_id,
     subresources_of=_subresources_of(
-        in_value={"additionalProperties", "if", "then", "else", "not"},
-        in_subarray={"allOf", "anyOf", "oneOf"},
-        in_subvalues={"$defs", "properties"},
+        in_value={
+            "additionalProperties",
+            "contains",
+            "contentSchema",
+            "else",
+            "if",
+            "items",
+            "not",
+            "propertyNames",
+            "then",
+            "unevaluatedItems",
+            "unevaluatedProperties",
+        },
+        in_subarray={"allOf", "anyOf", "oneOf", "prefixItems"},
+        in_subvalues={
+            "$defs",
+            "dependentSchemas",
+            "patternProperties",
+            "properties",
+        },
     ),
     anchors_in=_anchor,
 )
 DRAFT201909 = Specification(
     name="draft2019-09",
     id_of=_dollar_id,
-    subresources_of=_subresources_of(
-        in_value={"additionalProperties", "if", "then", "else", "not"},
+    subresources_of=_subresources_of_with_crazy_items(
+        in_value={
+            "additionalItems",
+            "additionalProperties",
+            "contains",
+            "contentSchema",
+            "if",
+            "then",
+            "else",
+            "not",
+            "propertyNames",
+            "unevaluatedItems",
+            "unevaluatedProperties",
+        },
         in_subarray={"allOf", "anyOf", "oneOf"},
-        in_subvalues={"$defs", "properties"},
+        in_subvalues={
+            "$defs",
+            "dependentSchemas",
+            "patternProperties",
+            "properties",
+        },
     ),
     anchors_in=_anchor_2019,
 )
 DRAFT7 = Specification(
     name="draft-07",
     id_of=_legacy_dollar_id,
-    subresources_of=_subresources_of(
-        in_value={"additionalProperties", "if", "then", "else", "not"},
+    subresources_of=_subresources_of_with_crazy_items_dependencies(
+        in_value={
+            "additionalItems",
+            "additionalProperties",
+            "contains",
+            "else",
+            "if",
+            "not",
+            "propertyNames",
+            "then",
+        },
         in_subarray={"allOf", "anyOf", "oneOf"},
-        in_subvalues={"definitions", "properties"},
+        in_subvalues={"definitions", "patternProperties", "properties"},
     ),
     anchors_in=_legacy_anchor_in_dollar_id,
 )
 DRAFT6 = Specification(
     name="draft-06",
     id_of=_legacy_dollar_id,
-    subresources_of=_subresources_of(
-        in_value={"additionalProperties", "not"},
+    subresources_of=_subresources_of_with_crazy_items_dependencies(
+        in_value={
+            "additionalItems",
+            "additionalProperties",
+            "contains",
+            "not",
+            "propertyNames",
+        },
         in_subarray={"allOf", "anyOf", "oneOf"},
-        in_subvalues={"definitions", "properties"},
+        in_subvalues={"definitions", "patternProperties", "properties"},
     ),
     anchors_in=_legacy_anchor_in_dollar_id,
 )
 DRAFT4 = Specification(
     name="draft-04",
     id_of=_legacy_id,
-    subresources_of=_subresources_of(
-        in_value={"additionalProperties", "not"},
+    subresources_of=_subresources_of_with_crazy_items_dependencies(
+        in_value={"additionalItems", "additionalProperties", "not"},
         in_subarray={"allOf", "anyOf", "oneOf"},
-        in_subvalues={"definitions", "properties"},
+        in_subvalues={"definitions", "patternProperties", "properties"},
     ),
     anchors_in=_legacy_anchor_in_id,
 )
 DRAFT3 = Specification(
     name="draft-03",
     id_of=_legacy_id,
-    subresources_of=_subresources_of(
-        in_value={"additionalProperties"},
+    subresources_of=_subresources_of_with_crazy_items_dependencies(
+        in_value={"additionalItems", "additionalProperties"},
         in_subarray={"extends"},
-        in_subvalues={"definitions", "properties"},
+        in_subvalues={"definitions", "patternProperties", "properties"},
     ),
     anchors_in=_legacy_anchor_in_id,
 )
