@@ -375,6 +375,39 @@ class TestResource:
             specification=Specification.OPAQUE,
         )
 
+    def test_retrieve(self):
+        foo = Resource.opaque({"foo": "bar"})
+        registry = Registry(retrieve=lambda uri: foo)
+        assert registry["urn:example"] == foo
+
+    def test_retrieve_error(self):
+        def retrieve(uri):
+            if uri == "urn:succeed":
+                return {}
+            raise Exception("Oh no!")
+
+        registry = Registry(retrieve=retrieve)
+        assert registry["urn:succeed"] == {}
+        with pytest.raises(exceptions.NoSuchResource):
+            registry["urn:uhoh"]
+
+    def test_retrieve_already_available_resource(self):
+        def retrieve(uri):
+            raise Exception("Oh no!")
+
+        foo = Resource.opaque({"foo": "bar"})
+        registry = Registry({"urn:example": foo})
+        assert registry["urn:example"] == foo
+
+    def test_retrieve_crawlable_resource(self):
+        def retrieve(uri):
+            raise Exception("Oh no!")
+
+        child = ID_AND_CHILDREN.create_resource({"ID": "urn:child", "foo": 12})
+        root = ID_AND_CHILDREN.create_resource({"children": [child.contents]})
+        registry = Registry(retrieve=retrieve).with_resource("urn:root", root)
+        assert registry.crawl()["urn:child"] == child
+
 
 class TestResolver:
     def test_lookup_exact_uri(self):
@@ -443,6 +476,21 @@ class TestResolver:
             resource=resource,
         )
 
+    def test_lookup_non_existent_anchor(self):
+        root = ID_AND_CHILDREN.create_resource({"anchors": {}})
+        resolver = Registry().with_resource("urn:example", root).resolver()
+        resolved = resolver.lookup("urn:example")
+        assert resolved.contents == root.contents
+
+        ref = "urn:example#noSuchAnchor"
+        with pytest.raises(exceptions.Unresolvable) as e:
+            resolver.lookup(ref)
+        assert e.value == exceptions.NoSuchAnchor(
+            ref=ref,
+            resource=root,
+            anchor="noSuchAnchor",
+        )
+
     # FIXME: Ideally there'd be some way to represent the tests below in the
     #        referencing suite, but I can't think of ways to do so yet.
 
@@ -596,7 +644,6 @@ class TestSpecification:
 
 
 class TestOpaqueSpecification:
-
     THINGS = [{"foo": "bar"}, True, 37, "foo", object()]
 
     @pytest.mark.parametrize("thing", THINGS)
